@@ -26,6 +26,8 @@ from .types.service import EmptyParams
 from .types.service import EmptyResponse
 from .types.service import Fleet
 from .types.service import Fleets
+from .types.service import GetFleetLiveMapRequest
+from .types.service import GetFleetLiveMapResponse
 from .types.service import GetFleetRequest
 from .types.service import ListVesselsRequest
 from .types.service import RenameFleetRequest
@@ -48,6 +50,8 @@ __all__ = (
     'EmptyResponse',
     'Fleet',
     'Fleets',
+    'GetFleetLiveMapRequest',
+    'GetFleetLiveMapResponse',
     'GetFleetRequest',
     'ListVesselsRequest',
     'RenameFleetRequest',
