@@ -984,6 +984,57 @@ class FleetManagementServiceClient(metaclass=FleetManagementServiceClientMeta):
         # Done; return the response.
         return response
 
+    def get_fleet_live_map(self,
+            request: service.GetFleetLiveMapRequest = None,
+            *,
+            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            timeout: float = None,
+            metadata: Sequence[Tuple[str, str]] = (),
+            ) -> service.GetFleetLiveMapResponse:
+        r"""GetFleetLiveMap display static location for vessels
+        in a fleet (as static image).
+
+        Args:
+            request (oceanbolt.com.fleetmanagement_v3.types.GetFleetLiveMapRequest):
+                The request object. GetFleetLiveMapRequest request
+                object for getting static fleet map
+
+            retry (google.api_core.retry.Retry): Designation of what errors, if any,
+                should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+
+        Returns:
+            oceanbolt.com.fleetmanagement_v3.types.GetFleetLiveMapResponse:
+                GetFleetLiveMapRequest request object
+                for getting static fleet map
+
+        """
+        # Create or coerce a protobuf request object.
+
+        # Minor optimization to avoid making a copy if the user passes
+        # in a service.GetFleetLiveMapRequest.
+        # There's no risk of modifying the input as we've already verified
+        # there are no flattened fields.
+        if not isinstance(request, service.GetFleetLiveMapRequest):
+            request = service.GetFleetLiveMapRequest(request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = self._transport._wrapped_methods[self._transport.get_fleet_live_map]
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
 
 
 
