@@ -610,6 +610,33 @@ class FleetManagementServiceGrpcAsyncIOTransport(FleetManagementServiceTransport
             )
         return self._stubs['drop_vessels']
 
+    @property
+    def get_fleet_live_map(self) -> Callable[
+            [service.GetFleetLiveMapRequest],
+            Awaitable[service.GetFleetLiveMapResponse]]:
+        r"""Return a callable for the get fleet live map method over gRPC.
+
+        GetFleetLiveMap display static location for vessels
+        in a fleet (as static image).
+
+        Returns:
+            Callable[[~.GetFleetLiveMapRequest],
+                    Awaitable[~.GetFleetLiveMapResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'get_fleet_live_map' not in self._stubs:
+            self._stubs['get_fleet_live_map'] = self.grpc_channel.unary_unary(
+                '/oceanbolt.com.fleetmanagement.v3.FleetManagementService/GetFleetLiveMap',
+                request_serializer=service.GetFleetLiveMapRequest.serialize,
+                response_deserializer=service.GetFleetLiveMapResponse.deserialize,
+            )
+        return self._stubs['get_fleet_live_map']
+
 
 __all__ = (
     'FleetManagementServiceGrpcAsyncIOTransport',
