@@ -375,6 +375,34 @@ class TradeFlowServiceGrpcAsyncIOTransport(TradeFlowServiceTransport):
             )
         return self._stubs['get_trade_flow_histogram']
 
+    @property
+    def get_location_volume(self) -> Callable[
+            [service.TradeFlowDataRequest],
+            Awaitable[service.GetLocationVolumeResponse]]:
+        r"""Return a callable for the get location volume method over gRPC.
+
+        GetLocationVolume gets location
+        (port/berth/country/region) flow stats for the given
+        filter parameters
+
+        Returns:
+            Callable[[~.TradeFlowDataRequest],
+                    Awaitable[~.GetLocationVolumeResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if 'get_location_volume' not in self._stubs:
+            self._stubs['get_location_volume'] = self.grpc_channel.unary_unary(
+                '/oceanbolt.com.tradeflows.v3.TradeFlowService/GetLocationVolume',
+                request_serializer=service.TradeFlowDataRequest.serialize,
+                response_deserializer=service.GetLocationVolumeResponse.deserialize,
+            )
+        return self._stubs['get_location_volume']
+
 
 __all__ = (
     'TradeFlowServiceGrpcAsyncIOTransport',
